pub struct DirectiveAnnotation<'src> {
pub arguments: Vec<Argument<'src>>,
pub name: Name<'src>,
pub span: ByteSpan,
pub syntax: Option<Box<DirectiveAnnotationSyntax<'src>>>,
}Expand description
A directive annotation applied to a definition or field
(e.g. @deprecated(reason: "Use newField")).
See Directives in the spec. Note: this represents an applied directive (an annotation), not a directive definition.
Fields
arguments: Vec<Argument<'src>>name: Name<'src>span: ByteSpansyntax: Option<Box<DirectiveAnnotationSyntax<'src>>>Implementations
Sourceimpl<'src> DirectiveAnnotation<'src>
impl<'src> DirectiveAnnotation<'src>
Sourcepub fn name_value(&self) -> &str
pub fn name_value(&self) -> &str
Returns the name of this directive annotation as a string slice.
Convenience accessor for self.name.value.
Sourceimpl DirectiveAnnotation<'_>
impl DirectiveAnnotation<'_>
Sourcepub fn append_source(&self, sink: &mut String, source: Option<&str>)
pub fn append_source(&self, sink: &mut String, source: Option<&str>)
Sourcepub fn byte_span(&self) -> ByteSpan
pub fn byte_span(&self) -> ByteSpan
Returns this directive annotation’s byte-offset span within the source text.
The returned ByteSpan can be resolved to line/column
positions via source_span() or
ByteSpan::resolve().
Sourcepub fn source_span(&self, source_map: &SourceMap<'_>) -> Option<SourceSpan>
pub fn source_span(&self, source_map: &SourceMap<'_>) -> Option<SourceSpan>