pub struct FieldSelection<'src> {
pub alias: Option<Name<'src>>,
pub arguments: Vec<Argument<'src>>,
pub directives: Vec<DirectiveAnnotation<'src>>,
pub name: Name<'src>,
pub selection_set: Option<SelectionSet<'src>>,
pub span: ByteSpan,
pub syntax: Option<Box<FieldSelectionSyntax<'src>>>,
}Expand description
A field selection within a selection set, optionally aliased, with arguments, directives, and a nested selection set.
See Fields in the spec.
Fields
alias: Option<Name<'src>>arguments: Vec<Argument<'src>>directives: Vec<DirectiveAnnotation<'src>>name: Name<'src>selection_set: Option<SelectionSet<'src>>span: ByteSpansyntax: Option<Box<FieldSelectionSyntax<'src>>>Implementations
Sourceimpl<'src> FieldSelection<'src>
impl<'src> FieldSelection<'src>
Sourcepub fn name_value(&self) -> &str
pub fn name_value(&self) -> &str
Returns the name of this field selection as a string slice.
Convenience accessor for self.name.value.
Sourceimpl FieldSelection<'_>
impl FieldSelection<'_>
Sourcepub fn append_source(&self, sink: &mut String, source: Option<&str>)
pub fn append_source(&self, sink: &mut String, source: Option<&str>)
Sourcepub fn byte_span(&self) -> ByteSpan
pub fn byte_span(&self) -> ByteSpan
Returns this field selection’s byte-offset span within the source text.
The returned ByteSpan can be resolved to line/column
positions via source_span() or
ByteSpan::resolve().
Sourcepub fn source_span(&self, source_map: &SourceMap<'_>) -> Option<SourceSpan>
pub fn source_span(&self, source_map: &SourceMap<'_>) -> Option<SourceSpan>