InputObjectTypeDefinition

Struct InputObjectTypeDefinition 

pub struct InputObjectTypeDefinition<'src> {
    pub description: Option<StringValue<'src>>,
    pub directives: Vec<DirectiveAnnotation<'src>>,
    pub fields: Vec<InputValueDefinition<'src>>,
    pub name: Name<'src>,
    pub span: ByteSpan,
    pub syntax: Option<Box<InputObjectTypeDefinitionSyntax<'src>>>,
}
An input object type definition.

See Input Objects in the spec.

Fields

description: Option<StringValue<'src>>directives: Vec<DirectiveAnnotation<'src>>fields: Vec<InputValueDefinition<'src>>name: Name<'src>span: ByteSpansyntax: Option<Box<InputObjectTypeDefinitionSyntax<'src>>>

Implementations

Source

impl<'src> InputObjectTypeDefinition<'src>

pub fn name_value(&self) -> &str

Returns the name of this input object type definition as a string slice.

Convenience accessor for self.name.value.

Source

impl InputObjectTypeDefinition<'_>

pub fn append_source(&self, sink: &mut String, source: Option<&str>)

pub fn byte_span(&self) -> ByteSpan

Returns this input object type definition’s byte-offset span within the source text.

The returned ByteSpan can be resolved to line/column positions via source_span() or ByteSpan::resolve().

pub fn source_span(&self, source_map: &SourceMap<'_>) -> Option<SourceSpan>

Resolves this input object type definition’s position to line/column coordinates using the given SourceMap.

Returns None if the byte offsets cannot be resolved (e.g. the span was synthetically constructed without valid position data).