ScalarTypeExtension

Struct ScalarTypeExtension 

pub struct ScalarTypeExtension<'src> {
    pub directives: Vec<DirectiveAnnotation<'src>>,
    pub name: Name<'src>,
    pub span: ByteSpan,
    pub syntax: Option<Box<ScalarTypeExtensionSyntax<'src>>>,
}
A scalar type extension.

See Scalar Extensions in the spec.

Spec invariant

The spec grammar requires at least one directive. For a spec-valid node, directives is always non-empty.

Fields

directives: Vec<DirectiveAnnotation<'src>>name: Name<'src>span: ByteSpansyntax: Option<Box<ScalarTypeExtensionSyntax<'src>>>

Implementations

Source

impl<'src> ScalarTypeExtension<'src>

pub fn name_value(&self) -> &str

Returns the name of this scalar type extension as a string slice.

Convenience accessor for self.name.value.

Source

impl ScalarTypeExtension<'_>

pub fn append_source(&self, sink: &mut String, source: Option<&str>)

pub fn byte_span(&self) -> ByteSpan

Returns this scalar type extension’s byte-offset span within the source text.

The returned ByteSpan can be resolved to line/column positions via source_span() or ByteSpan::resolve().

pub fn source_span(&self, source_map: &SourceMap<'_>) -> Option<SourceSpan>

Resolves this scalar type extension’s position to line/column coordinates using the given SourceMap.

Returns None if the byte offsets cannot be resolved (e.g. the span was synthetically constructed without valid position data).