VariableDefinition

Struct VariableDefinition 

pub struct VariableDefinition<'src> {
    pub default_value: Option<Value<'src>>,
    pub description: Option<StringValue<'src>>,
    pub directives: Vec<DirectiveAnnotation<'src>>,
    pub span: ByteSpan,
    pub syntax: Option<Box<VariableDefinitionSyntax<'src>>>,
    pub var_type: TypeAnnotation<'src>,
    pub variable: Name<'src>,
}
A variable definition within an operation’s variable list (e.g. $id: ID! = "default").

See Variable Definitions in the spec.

Fields

default_value: Option<Value<'src>>description: Option<StringValue<'src>>directives: Vec<DirectiveAnnotation<'src>>span: ByteSpansyntax: Option<Box<VariableDefinitionSyntax<'src>>>var_type: TypeAnnotation<'src>variable: Name<'src>

Implementations

Source

impl VariableDefinition<'_>

pub fn append_source(&self, sink: &mut String, source: Option<&str>)

pub fn byte_span(&self) -> ByteSpan

Returns this variable definition’s byte-offset span within the source text.

The returned ByteSpan can be resolved to line/column positions via source_span() or ByteSpan::resolve().

pub fn source_span(&self, source_map: &SourceMap<'_>) -> Option<SourceSpan>

Resolves this variable definition’s position to line/column coordinates using the given SourceMap.

Returns None if the byte offsets cannot be resolved (e.g. the span was synthetically constructed without valid position data).