Module graphql_parser_v0_4

Module graphql_parser_v0_4 

Compatibility layer for converting between the libgraphql AST (crate::ast) and graphql_parser v0.4 types.

See Section 9.2 of the AST design plan for the full conversion specification.

Functions

from_graphql_parser_query_ast
Convert a graphql_parser query Document to a libgraphql AST Document.
from_graphql_parser_query_ast_with_source
Like from_graphql_parser_query_ast, but computes byte offsets from the source text for accurate ByteSpan byte offset values.
from_graphql_parser_schema_ast
Convert a graphql_parser schema Document to a libgraphql AST Document.
from_graphql_parser_schema_ast_with_source
Like from_graphql_parser_schema_ast, but computes byte offsets from the source text for accurate ByteSpan byte offset values.
to_graphql_parser_query_ast
Convert a libgraphql AST Document to a graphql_parser query Document.
to_graphql_parser_schema_ast
Convert a libgraphql AST Document to a graphql_parser schema Document.