GraphQLSourceSpan

Struct GraphQLSourceSpan 

pub struct GraphQLSourceSpan {
    pub start_inclusive: SourcePosition,
    pub end_exclusive: SourcePosition,
    pub file_path: Option<PathBuf>,
}
Represents a span of source text from start to end position.

The span is a half-open interval: [start_inclusive, end_exclusive).

  • start_inclusive: Position of the first character of the source text
  • end_exclusive: Position immediately after the last character

Optionally includes a file path for the referenced source text.

Fields

start_inclusive: SourcePositionend_exclusive: SourcePositionfile_path: Option<PathBuf>

The file path to the source text this span refers to, if available.

Implementations

Source

impl GraphQLSourceSpan

pub fn new(start: SourcePosition, end: SourcePosition) -> Self

Creates a span without file path information.

pub fn with_file( start: SourcePosition, end: SourcePosition, file_path: PathBuf, ) -> Self

Creates a span with file path information.