GraphQLToken

Struct GraphQLToken 

pub struct GraphQLToken<'src> {
    pub kind: GraphQLTokenKind<'src>,
    pub preceding_trivia: GraphQLTriviaTokenVec<'src>,
    pub span: GraphQLSourceSpan,
}
A GraphQL token with location (span) information and an ordered list of any preceding trivia (comments, commas).

Trivia is attached to the following token, so parsers can simply call peek() and consume() without worrying about skipping trivia.

Lifetime Parameter

The 'src lifetime represents the source text that this token was lexed from. For StrGraphQLTokenSource, this enables zero-copy lexing where token values borrow directly from the input string. For RustMacroGraphQLTokenSource, tokens use owned strings and the lifetime can be 'static.

Fields

kind: GraphQLTokenKind<'src>

The kind of token (including Error for lexer errors).

preceding_trivia: GraphQLTriviaTokenVec<'src>

Trivia (comments, commas) that precede this token.

span: GraphQLSourceSpan

The source location span of this token.

Implementations

Source

impl<'src> GraphQLToken<'src>

pub fn new(kind: GraphQLTokenKind<'src>, span: GraphQLSourceSpan) -> Self

Convenience constructor for a token with no preceding trivia.