pub enum TypeExtension<'src> {
Enum(EnumTypeExtension<'src>),
InputObject(InputObjectTypeExtension<'src>),
Interface(InterfaceTypeExtension<'src>),
Object(ObjectTypeExtension<'src>),
Scalar(ScalarTypeExtension<'src>),
Union(UnionTypeExtension<'src>),
}Expand description
A type extension in a GraphQL schema.
See Type Extensions in the spec.
Variants
Enum(EnumTypeExtension<'src>)
InputObject(InputObjectTypeExtension<'src>)
Interface(InterfaceTypeExtension<'src>)
Object(ObjectTypeExtension<'src>)
Scalar(ScalarTypeExtension<'src>)
Union(UnionTypeExtension<'src>)
Implementations
Sourceimpl<'src> TypeExtension<'src>
impl<'src> TypeExtension<'src>
Sourcepub fn directive_annotations(&self) -> &[DirectiveAnnotation<'src>]
pub fn directive_annotations(&self) -> &[DirectiveAnnotation<'src>]
Returns the directive annotations applied to this type extension.
Sourcepub fn name_value(&self) -> &str
pub fn name_value(&self) -> &str
Returns the name of this type extension as a string slice.
Convenience accessor for self.name().value.
Sourceimpl TypeExtension<'_>
impl TypeExtension<'_>
Sourcepub fn append_source(&self, sink: &mut String, source: Option<&str>)
pub fn append_source(&self, sink: &mut String, source: Option<&str>)
Sourcepub fn byte_span(&self) -> ByteSpan
pub fn byte_span(&self) -> ByteSpan
Returns this type extension’s byte-offset span within the source text.
The returned ByteSpan can be resolved to line/column
positions via source_span() or
ByteSpan::resolve().
Sourcepub fn source_span(&self, source_map: &SourceMap<'_>) -> Option<SourceSpan>
pub fn source_span(&self, source_map: &SourceMap<'_>) -> Option<SourceSpan>