pub struct Argument<'src> {
pub name: Name<'src>,
pub span: ByteSpan,
pub syntax: Option<Box<ArgumentSyntax<'src>>>,
pub value: Value<'src>,
}Expand description
A single argument in a field selection or directive annotation.
See Arguments in the spec.
Fields
name: Name<'src>span: ByteSpansyntax: Option<Box<ArgumentSyntax<'src>>>value: Value<'src>Implementations
Sourceimpl<'src> Argument<'src>
impl<'src> Argument<'src>
Sourcepub fn name_value(&self) -> &str
pub fn name_value(&self) -> &str
Returns the name of this argument as a string slice.
Convenience accessor for self.name.value.
Sourceimpl Argument<'_>
impl Argument<'_>
Sourcepub fn append_source(&self, sink: &mut String, source: Option<&str>)
pub fn append_source(&self, sink: &mut String, source: Option<&str>)
Sourcepub fn byte_span(&self) -> ByteSpan
pub fn byte_span(&self) -> ByteSpan
Returns this argument’s byte-offset span within the source text.
The returned ByteSpan can be resolved to line/column
positions via source_span() or
ByteSpan::resolve().
Sourcepub fn source_span(&self, source_map: &SourceMap<'_>) -> Option<SourceSpan>
pub fn source_span(&self, source_map: &SourceMap<'_>) -> Option<SourceSpan>