pub struct FieldDefinition<'src> {
pub parameters: Vec<InputValueDefinition<'src>>,
pub description: Option<StringValue<'src>>,
pub directives: Vec<DirectiveAnnotation<'src>>,
pub field_type: TypeAnnotation<'src>,
pub name: Name<'src>,
pub span: ByteSpan,
pub syntax: Option<Box<FieldDefinitionSyntax<'src>>>,
}Expand description
A field definition within an object type or interface type.
See Field Definitions in the spec.
Fields
parameters: Vec<InputValueDefinition<'src>>description: Option<StringValue<'src>>directives: Vec<DirectiveAnnotation<'src>>field_type: TypeAnnotation<'src>name: Name<'src>span: ByteSpansyntax: Option<Box<FieldDefinitionSyntax<'src>>>Implementations
Sourceimpl<'src> FieldDefinition<'src>
impl<'src> FieldDefinition<'src>
Sourcepub fn name_value(&self) -> &str
pub fn name_value(&self) -> &str
Returns the name of this field definition as a string slice.
Convenience accessor for self.name.value.
Sourceimpl FieldDefinition<'_>
impl FieldDefinition<'_>
Sourcepub fn append_source(&self, sink: &mut String, source: Option<&str>)
pub fn append_source(&self, sink: &mut String, source: Option<&str>)
Sourcepub fn byte_span(&self) -> ByteSpan
pub fn byte_span(&self) -> ByteSpan
Returns this field definition’s byte-offset span within the source text.
The returned ByteSpan can be resolved to line/column
positions via source_span() or
ByteSpan::resolve().
Sourcepub fn source_span(&self, source_map: &SourceMap<'_>) -> Option<SourceSpan>
pub fn source_span(&self, source_map: &SourceMap<'_>) -> Option<SourceSpan>