pub struct InputValueDefinition<'src> {
pub default_value: Option<Value<'src>>,
pub description: Option<StringValue<'src>>,
pub directives: Vec<DirectiveAnnotation<'src>>,
pub name: Name<'src>,
pub span: ByteSpan,
pub syntax: Option<Box<InputValueDefinitionSyntax<'src>>>,
pub value_type: TypeAnnotation<'src>,
}Expand description
An input value definition, used for field arguments and input object fields.
See Input Values Definitions in the spec.
Fields
default_value: Option<Value<'src>>description: Option<StringValue<'src>>directives: Vec<DirectiveAnnotation<'src>>name: Name<'src>span: ByteSpansyntax: Option<Box<InputValueDefinitionSyntax<'src>>>value_type: TypeAnnotation<'src>Implementations
Sourceimpl<'src> InputValueDefinition<'src>
impl<'src> InputValueDefinition<'src>
Sourcepub fn name_value(&self) -> &str
pub fn name_value(&self) -> &str
Returns the name of this input value definition as a string slice.
Convenience accessor for self.name.value.
Sourceimpl InputValueDefinition<'_>
impl InputValueDefinition<'_>
Sourcepub fn append_source(&self, sink: &mut String, source: Option<&str>)
pub fn append_source(&self, sink: &mut String, source: Option<&str>)
Sourcepub fn byte_span(&self) -> ByteSpan
pub fn byte_span(&self) -> ByteSpan
Returns this input value definition’s byte-offset span within the source text.
The returned ByteSpan can be resolved to line/column
positions via source_span() or
ByteSpan::resolve().
Sourcepub fn source_span(&self, source_map: &SourceMap<'_>) -> Option<SourceSpan>
pub fn source_span(&self, source_map: &SourceMap<'_>) -> Option<SourceSpan>