pub struct Name<'src> {
pub span: ByteSpan,
pub syntax: Option<Box<NameSyntax<'src>>>,
pub value: Cow<'src, str>,
}Expand description
A GraphQL name (identifier).
Names are used for type names, field names, argument names,
directive names, enum values, and more. The value field
borrows from the source text when possible
(Cow::Borrowed) or owns the string when the source is not
available (Cow::Owned).
Syntax Layer
When the parser retains syntax detail, syntax contains the
underlying GraphQLToken with any leading trivia
(whitespace, comments, commas).
Fields
span: ByteSpansyntax: Option<Box<NameSyntax<'src>>>value: Cow<'src, str>Implementations
Sourceimpl Name<'_>
impl Name<'_>
Sourcepub fn append_source(&self, sink: &mut String, source: Option<&str>)
pub fn append_source(&self, sink: &mut String, source: Option<&str>)
Sourcepub fn byte_span(&self) -> ByteSpan
pub fn byte_span(&self) -> ByteSpan
Returns this name’s byte-offset span within the source text.
The returned ByteSpan can be resolved to line/column
positions via source_span() or
ByteSpan::resolve().
Sourcepub fn source_span(&self, source_map: &SourceMap<'_>) -> Option<SourceSpan>
pub fn source_span(&self, source_map: &SourceMap<'_>) -> Option<SourceSpan>