Compatibility layer for converting between the
libgraphql AST (crate::ast) and graphql_parser
v0.4 types.
See Section 9.2 of the AST design plan for the full conversion specification.
Functions
- from_
graphql_ parser_ query_ ast - Convert a
graphql_parserqueryDocumentto a libgraphql ASTDocument. - from_
graphql_ parser_ query_ ast_ with_ source - Like
from_graphql_parser_query_ast, but computes byte offsets from the source text for accurateByteSpanbyte offset values. - from_
graphql_ parser_ schema_ ast - Convert a
graphql_parserschemaDocumentto a libgraphql ASTDocument. - from_
graphql_ parser_ schema_ ast_ with_ source - Like
from_graphql_parser_schema_ast, but computes byte offsets from the source text for accurateByteSpanbyte offset values. - to_
graphql_ parser_ query_ ast - Convert a libgraphql AST
Documentto agraphql_parserqueryDocument. - to_
graphql_ parser_ schema_ ast - Convert a libgraphql AST
Documentto agraphql_parserschemaDocument.