This module provides the core token types used by GraphQL lexers and the parser.
Structs
- GraphQL
Token - A GraphQL token with location (span) information and an ordered list of any preceding trivia (comments, commas).
Enums
- GraphQL
Token Kind - The kind of a GraphQL token.
- GraphQL
Trivia Token - A “trivia token” is a token that doesn’t affect parsing but is still preserved (e.g. for tooling use).
Type Aliases
- GraphQL
Trivia Token Vec - Type alias for trivia storage. Uses SmallVec to avoid heap allocation for the common case of 0-2 trivia items per token.